==> snips-sam-0.0.7.tgz: package/docs/tutorials/index.md <==
---
layout: article
title:  "Tutorials"
permalink: /tutorials/
---

Various resources and examples for building private voice assistants using Snips.

<hr class="doc" />

<ul class="tutorial">
    {% include tutorial_link.html
        article_id='sonos'
        title='Buidling a Sonos system with custom Spotify playlists'
        description='A step-by-step guide to building a voice-powered Sonos music system.' %}
    {% include tutorial_link.html
        article_id='calculator'
        title='Skills 101: building a simple calculator skill'
        description='A tutorial on building a skill performing basic arithmetic operations using the Snipsfile.' %}
    <!-- {% include tutorial_link.html
        article_id='mqtt-js'
        title='Listening to intents over MQTT using Javascript'
        description='Snips works by sending messages, at various stages in the pipeline, over MQTT. Learn how to obtain these messages to build custom behaviour into your assistant.' %} -->
    {% include tutorial_link.html
        article_id='homeassistant'
        title='Integrating Snips with Home Assistant'
        description='Add on-device voice capabilities to your Home Assistant setups.' %}
    {% include tutorial_link.html
        article_id='networking'
        title='Connecting a Raspberry Pi to the local network'
        description='A guide to get your Raspberry Pi connected to the local network over Wi-Fi.' %}
    {% include tutorial_link.html
        article_id='raspberry-pi-setup'
        title='Raspberry Pi Setup'
        description='A short note on how to set up a Raspberry Pi from scratch.' %}
</ul>

==> snips-sam-0.0.15.tgz: package/docs/tutorials/index.md <==
---
layout: article
title:  "Tutorials"
permalink: /tutorials/
---

Various resources and examples for building private voice assistants using Snips.

<hr class="doc" />

<ul class="tutorial">
    {% include tutorial_link.html
        article_id='sonos'
        title='Buidling a Sonos system with custom Spotify playlists'
        description='A step-by-step guide to building a voice-powered Sonos music system.' %}
    {% include tutorial_link.html
        article_id='calculator'
        title='Skills 101: building a simple calculator skill'
        description='A tutorial on building a skill performing basic arithmetic operations using the Snipsfile.' %}
    {% include tutorial_link.html
        article_id='mqtt-js'
        title='Listening to intents over MQTT using Javascript'
        description='Write a simple MQTT client in Javascript capable of reacting to messages received from the Snips platform.' %}
    {% include tutorial_link.html
        article_id='mqtt-python'
        title='Listening to intents over MQTT using Python'
        description='Write a simple MQTT client in Python capable of reacting to messages received from the Snips platform.' %}
    <!-- {% include tutorial_link.html
        article_id='homeassistant'
        title='Integrating Snips with Home Assistant'
        description='Add on-device voice capabilities to your Home Assistant setups.' %} -->
    {% include tutorial_link.html
        article_id='networking'
        title='Connecting a Raspberry Pi to the local network'
        description='A guide to get your Raspberry Pi connected to the local network over Wi-Fi.' %}
    <!-- {% include tutorial_link.html
        article_id='raspberry-pi-setup'
        title='Raspberry Pi Setup'
        description='A short note on how to set up a Raspberry Pi from scratch.' %} -->
</ul>
